#include "Maiden_struct.h"
#include "Constants.h"
#include <math.h>
#include <stdio.h>
#ifdef __APPLE__
#include "malloc.h"
#else
#include <malloc.h>
#endif

int radtrans(const param_struct *par, meteo_struct *meteo, radiation_struct *rad,
			 allocation_struct *alloc, int i)
{
	/* calculate the projected leaf area for sun and shade fractions
	and the canopy transmission and absorption of shortwave radiation
	based on the Beer's Law assumption of radiation attenuation as a
	function of projected LAI.
	*/

	int ok=1;
	double albedo_par;
	/*double par_top;
	double parabs;
	double parabs_plaisun, parabs_plaishade;
	double parabs_per_plaisun, parabs_per_plaishade; */

	/* The following equations estimate the albedo and extinction
	coefficients for the shortwave and PAR spectra from the values given for the
	entire shortwave range (from Jones, H.G., 1992. Plants and Microclimate,
	2nd	Edition. Cambridge University Press. pp. 30-38.) These conversions
	are approximated from the information given in Jones.
	*/

	// Initialisation
	if (i == 0)
	{
		if (exp_site == 1) alloc->LAI[i] = 0.0;
		if (exp_site == 2) alloc->LAI[i] = par->LAImax*(1-exp( -par->C_stem_init / par->lai_par));
	}

	/* Calculate projected LAI for sunlit and shaded canopy portions */ // FG see K sheet of Parameters_FG.xlsx
	rad->plaisun[i] = 1.0 - exp(-alloc->LAI[i]);
	rad->plaishade[i] = alloc->LAI[i] - rad->plaisun[i];

	//printf("%lf\n",rad->plaishade[0]);

	/* calculate PAR absorbed */
	albedo_par = albedo_sw / 3.0;
	rad->par_top[i] = meteo->s_par[i] * (1.0 - albedo_par);

	//printf("%lf\n",meteo->s_par[i]);
	rad->parabs[i] = rad->par_top[i] * (1.0 - exp(-par->k*alloc->LAI[i]));

	/* calculate the total PAR absorbed by the sunlit and
	shaded canopy fractions */
	rad->parabs_plaisun[i] = par->k * rad->par_top[i] * rad->plaisun[i];
	rad->parabs_plaishade[i] = rad->parabs[i] - rad->parabs_plaisun[i];

	//printf("%i %lf\n",i,rad->plaishade[0]);

	/* convert this to the PAR absorbed per unit LAI in the sunlit and
	shaded canopy fractions */

	if (alloc->LAI[i] < 0.01)
	{
		rad->parabs_per_plaisun[i] = 0.0;
		rad->parabs_per_plaishade[i] = 0.0;
	}
	else
	{
		rad->parabs_per_plaisun[i] = rad->parabs_plaisun[i]/rad->plaisun[i];
		rad->parabs_per_plaishade[i] = rad->parabs_plaishade[i]/rad->plaishade[i];
	}

	/* calculate PPFD (Photosynthetic Photon Flux Density): assumes an average energy for PAR photon (EPAR, umol/J)
	unit conversion: W/m2 --> umol/m2/s. */
	rad->ppfd_per_plaisun[i] = rad->parabs_per_plaisun[i] * EPAR;
	rad->ppfd_per_plaishade[i] = rad->parabs_per_plaishade[i] * EPAR;

	return (!ok);
}

